@@ -84,7 +84,7 @@
 #define KCOREADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOREADDONS_NO_DEPRECATED
-#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57200
 #endif
 #ifdef KCOREADDONS_NO_DEPRECATED_WARNINGS
 #  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x57200
 #  endif
 #endif
 
@@ -233,6 +233,12 @@
 #else
 #  define KCOREADDONS_DEPRECATED_VERSION_5_104(text)
 #endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x57000
+#  define KCOREADDONS_DEPRECATED_VERSION_5_112(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_112(text)
+#endif
 #define KCOREADDONS_DEPRECATED_VERSION_4(minor, text)      KCOREADDONS_DEPRECATED_VERSION_4_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION_5(minor, text)      KCOREADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION(major, minor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
